<?php

namespace App\Http\Controllers\Member;

use App\Helper\Files;
use App\Helper\Reply;
use App\Lead;
use App\LeadFiles;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\File;
use Illuminate\Support\Facades\Storage;

class LeadFilesController extends MemberBaseController
{

    private $mimeType = [
        'txt' => 'fa-file-text',
        'htm' => 'fa-file-code-o',
        'html' => 'fa-file-code-o',
        'php' => 'fa-file-code-o',
        'css' => 'fa-file-code-o',
        'js' => 'fa-file-code-o',
        'json' => 'fa-file-code-o',
        'xml' => 'fa-file-code-o',
        'swf' => 'fa-file-o',
        'flv' => 'fa-file-video-o',

        // images
        'png' => 'fa-file-image-o',
        'jpe' => 'fa-file-image-o',
        'jpeg' => 'fa-file-image-o',
        'jpg' => 'fa-file-image-o',
        'gif' => 'fa-file-image-o',
        'bmp' => 'fa-file-image-o',
        'ico' => 'fa-file-image-o',
        'tiff' => 'fa-file-image-o',
        'tif' => 'fa-file-image-o',
        'svg' => 'fa-file-image-o',
        'svgz' => 'fa-file-image-o',

        // archives
        'zip' => 'fa-file-o',
        'rar' => 'fa-file-o',
        'exe' => 'fa-file-o',
        'msi' => 'fa-file-o',
        'cab' => 'fa-file-o',

        // audio/video
        'mp3' => 'fa-file-audio-o',
        'qt' => 'fa-file-video-o',
        'mov' => 'fa-file-video-o',
        'mp4' => 'fa-file-video-o',
        'mkv' => 'fa-file-video-o',
        'avi' => 'fa-file-video-o',
        'wmv' => 'fa-file-video-o',
        'mpg' => 'fa-file-video-o',
        'mp2' => 'fa-file-video-o',
        'mpeg' => 'fa-file-video-o',
        'mpe' => 'fa-file-video-o',
        'mpv' => 'fa-file-video-o',
        '3gp' => 'fa-file-video-o',
        'm4v' => 'fa-file-video-o',

        // adobe
        'pdf' => 'fa-file-pdf-o',
        'psd' => 'fa-file-image-o',
        'ai' => 'fa-file-o',
        'eps' => 'fa-file-o',
        'ps' => 'fa-file-o',

        // ms office
        'doc' => 'fa-file-text',
        'rtf' => 'fa-file-text',
        'xls' => 'fa-file-excel-o',
        'ppt' => 'fa-file-powerpoint-o',
        'docx' => 'fa-file-text',
        'xlsx' => 'fa-file-excel-o',
        'pptx' => 'fa-file-powerpoint-o',


        // open office
        'odt' => 'fa-file-text',
        'ods' => 'fa-file-text',
    ];

    /**
     * ManageLeadFilesController constructor.
     */
    public function __construct()
    {
        parent::__construct();
        $this->pageIcon = 'icon-layers';
        $this->pageTitle = 'app.menu.leadFiles';

    }

    /**
     * Display a listing of the resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function index()
    {
        //
    }

    /**
     * Show the form for creating a new resource.
     *
     * @return \Illuminate\Http\Response
     */
    public function create()
    {
        //
    }

    /**
     * @param Request $request
     * @return array
     * @throws \GuzzleHttp\Exception\GuzzleException
     * @throws \Throwable
     */
    public function store(Request $request)
    {
        if ($request->hasFile('file')) {
            $storage = config('filesystems.default');
            $upload = can_upload($request->file->getSize() / (1000 * 1024));
            if($upload) {
                $file = new LeadFiles();
                $file->user_id = $this->user->id;
                $file->lead_id = $request->lead_id;
                $file->hashname = Files::uploadLocalOrS3($request->file, 'lead-files/'.$request->lead_id);
                $file->filename = $request->file->getClientOriginalName();
                $file->size = $request->file->getSize();
                $file->save();
            } else {
                return Reply::error(__('messages.storageLimitExceedContactAdmin'));
            }
        }

        $this->lead = Lead::findOrFail($request->lead_id);
        $this->icon($this->lead);
        if($request->view == 'list') {
            $view = view('member.lead.lead-files.ajax-list', $this->data)->render();
        } else {
            $view = view('member.lead.lead-files.thumbnail-list', $this->data)->render();
        }
        return Reply::successWithData(__('messages.fileUploaded'), ['html' => $view]);
    }

    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function show($id)
    {
        $this->lead = Lead::findOrFail($id);
        $this->upload = can_upload();
        return view('member.lead.lead-files.show', $this->data);
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function edit($id)
    {
        //
    }

    /**
     * Update the specified resource in storage.
     *
     * @param  \Illuminate\Http\Request  $request
     * @param  int  $id
     * @return \Illuminate\Http\Response
     */
    public function update(Request $request, $id)
    {
        //
    }

    /**
     * @param Request $request
     * @param $id
     * @return array
     * @throws \Throwable
     */
    public function destroy(Request $request, $id)
    {
        $storage = config('filesystems.default');
        $file = LeadFiles::findOrFail($id);
        switch($storage) {
        case 'local':
            Files::deleteFile($file->hashname, 'lead-files/'.$file->lead_id);
                break;
        case 's3':
            Storage::disk('s3')->delete('lead-files/'.$file->lead_id.'/'.$file->hashname);
            Files::deleteFile($file->hashname, 'lead-files/'.$file->lead_id);
                break;

        }
        LeadFiles::destroy($id);
        $this->lead = Lead::findOrFail($file->lead_id);
        $this->icon($this->lead);
        if($request->view == 'list') {
            $view = view('member.lead.lead-files.ajax-list', $this->data)->render();
        } else {
            $view = view('member.lead.lead-files.thumbnail-list', $this->data)->render();
        }
        return Reply::successWithData(__('messages.fileDeleted'), ['html' => $view]);
    }

    /**
     * @param $id
     * @return \Symfony\Component\HttpFoundation\BinaryFileResponse|\Symfony\Component\HttpFoundation\StreamedResponse
     */
    public function download($id)
    {
        $file = LeadFiles::findOrFail($id);
        return download_local_s3($file, 'lead-files/' . $file->lead_id . '/' . $file->hashname);
    }

    /**
     * @param Request $request
     * @return mixed
     * @throws \Throwable
     */
    public function thumbnailShow(Request $request)
    {
        $this->lead = Lead::with('files')->findOrFail($request->id);
        $this->icon($this->lead);
        $view = view('member.lead.lead-files.thumbnail-list', $this->data)->render();
        return Reply::dataOnly(['status' => 'success', 'view' => $view]);
    }

    /**
     * @param $leads
     */
    private function icon($leads)
    {
        foreach ($leads->files as $lead) {
            $ext = pathinfo($lead->filename, PATHINFO_EXTENSION);
            if ($ext == 'png' || $ext == 'jpe' || $ext == 'jpeg' || $ext == 'jpg' || $ext == 'gif' || $ext == 'bmp' ||
                $ext == 'ico' || $ext == 'tiff' || $ext == 'tif' || $ext == 'svg' || $ext == 'svgz' || $ext == 'psd')
            {
                $lead->icon = 'images';
            } else {
                $lead->icon = $this->mimeType[$ext];
            }
        }
    }

}
